@@ -8,7 +8,7 @@ use IO::File;
 use IO::Socket;
 use IO::Select;
 
-our $VERSION = "1.1915";
+our $VERSION = "1.1916";
 
 BEGIN {
     # I'd really rather the pause/cpan indexers miss this "package"
@@ -413,15 +413,23 @@ sub list {
 }
 
 sub search {
-    my ($self, $search) = @_;
-    $search ||= "ALL";
+    my ($self, $search, $sort, $charset) = @_;
+    $search   ||= "ALL";
+    $charset  ||= 'UTF-8';
+    my $cmd   = 'SEARCH';
+
+    # add rfc5256 sort, requires charset :(
+    if ($sort) {
+        $sort = uc $sort;
+        $cmd = "SORT ($sort) \"$charset\"";
+    }
 
     my @seq;
 
     return $self->_process_cmd(
-        cmd => [ SEARCH => $search ],
+        cmd => [ $cmd => $search ],
         final => sub { wantarray ? @seq : int @seq },
-        process => sub { if ( my ($msgs) = $_[0] =~ /^\*\s+SEARCH\s+(.*)/i ) {
+        process => sub { if ( my ($msgs) = $_[0] =~ /^\*\s+(?:SEARCH|SORT)\s+(.*)/i ) {
             push @seq, $1 while $msgs =~ m/\b(\d+)\b/g;
         } },
     );
